% vf.m
%
% Imlements the fisher-kpp traveling wave ODE
%   dx/dt = y
%   dy/dt =-cy - u(1-u)

%
% Inputs:
%   t - Time variable: not used here because our equation
%       is independent of time, or 'autonomous'.
%   x - Independent variable: has 3 dimensions
%   p - parameters, enter in the solver file
% Output:
%   dx - First derivative: the rate of change of the three dimension
%        values over time, given the values of each dimension
function dx = vf(t, x, p)

% Standard constants for the Lorenz Attractor
a = p(1);
b = p(2);

%rho = p(2);
%beta = p(3);

dx = [0;0];



dx(1) = a - x(1) - 4*x(1).*x(2)./(1+x(1).^2);
dx(2) =b*x(1).*(1-x(2)./(1+x(1).^2));
%dx(3) = x(1)*x(2)-beta*x(3);
